==> zio-aws-appmesh_2.13-5.17.124.1-sources.jar: zio/aws/appmesh/model/UpdateRouteRequest.scala <==
package zio.aws.appmesh.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.appmesh.model.primitives.{AccountId, ResourceName}
import scala.jdk.CollectionConverters._
final case class UpdateRouteRequest(
    clientToken: Option[String] = None,
    meshName: ResourceName,
    meshOwner: Option[AccountId] = None,
    routeName: ResourceName,
    spec: zio.aws.appmesh.model.RouteSpec,
    virtualRouterName: ResourceName
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.appmesh.model.UpdateRouteRequest = {
    import UpdateRouteRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.appmesh.model.UpdateRouteRequest
      .builder()
      .optionallyWith(clientToken.map(value => value: java.lang.String))(
        _.clientToken
      )
      .meshName(ResourceName.unwrap(meshName): java.lang.String)
      .optionallyWith(
        meshOwner.map(value => AccountId.unwrap(value): java.lang.String)
      )(_.meshOwner)
      .routeName(ResourceName.unwrap(routeName): java.lang.String)
      .spec(spec.buildAwsValue())
      .virtualRouterName(
        ResourceName.unwrap(virtualRouterName): java.lang.String
      )
      .build()
  }
  def asReadOnly: zio.aws.appmesh.model.UpdateRouteRequest.ReadOnly =
    zio.aws.appmesh.model.UpdateRouteRequest.wrap(buildAwsValue())
}
object UpdateRouteRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.appmesh.model.UpdateRouteRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.appmesh.model.UpdateRouteRequest =
      zio.aws.appmesh.model.UpdateRouteRequest(
        clientToken.map(value => value),
        meshName,
        meshOwner.map(value => value),
        routeName,
        spec.asEditable,
        virtualRouterName
      )
    def clientToken: Option[String]
    def meshName: ResourceName
    def meshOwner: Option[AccountId]
    def routeName: ResourceName
    def spec: zio.aws.appmesh.model.RouteSpec.ReadOnly
    def virtualRouterName: ResourceName
    def getClientToken: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("clientToken", clientToken)
    def getMeshName: ZIO[Any, Nothing, ResourceName] = ZIO.succeed(meshName)
    def getMeshOwner: ZIO[Any, AwsError, AccountId] =
      AwsError.unwrapOptionField("meshOwner", meshOwner)
    def getRouteName: ZIO[Any, Nothing, ResourceName] = ZIO.succeed(routeName)
    def getSpec: ZIO[Any, Nothing, zio.aws.appmesh.model.RouteSpec.ReadOnly] =
      ZIO.succeed(spec)
    def getVirtualRouterName: ZIO[Any, Nothing, ResourceName] =
      ZIO.succeed(virtualRouterName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.appmesh.model.UpdateRouteRequest
  ) extends zio.aws.appmesh.model.UpdateRouteRequest.ReadOnly {
    override val clientToken: Option[String] =
      scala.Option(impl.clientToken()).map(value => value: String)
    override val meshName: ResourceName =
      zio.aws.appmesh.model.primitives.ResourceName(impl.meshName())
    override val meshOwner: Option[AccountId] = scala
      .Option(impl.meshOwner())
      .map(value => zio.aws.appmesh.model.primitives.AccountId(value))
    override val routeName: ResourceName =
      zio.aws.appmesh.model.primitives.ResourceName(impl.routeName())
    override val spec: zio.aws.appmesh.model.RouteSpec.ReadOnly =
      zio.aws.appmesh.model.RouteSpec.wrap(impl.spec())
    override val virtualRouterName: ResourceName =
      zio.aws.appmesh.model.primitives.ResourceName(impl.virtualRouterName())
  }
  def wrap(
      impl: software.amazon.awssdk.services.appmesh.model.UpdateRouteRequest
  ): zio.aws.appmesh.model.UpdateRouteRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-appmesh_2.13-5.20.7.3-sources.jar: zio/aws/appmesh/model/UpdateRouteRequest.scala <==
package zio.aws.appmesh.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.appmesh.model.primitives.{AccountId, ResourceName}
import scala.jdk.CollectionConverters._
final case class UpdateRouteRequest(
    clientToken: Optional[String] = Optional.Absent,
    meshName: ResourceName,
    meshOwner: Optional[AccountId] = Optional.Absent,
    routeName: ResourceName,
    spec: zio.aws.appmesh.model.RouteSpec,
    virtualRouterName: ResourceName
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.appmesh.model.UpdateRouteRequest = {
    import UpdateRouteRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.appmesh.model.UpdateRouteRequest
      .builder()
      .optionallyWith(clientToken.map(value => value: java.lang.String))(
        _.clientToken
      )
      .meshName(ResourceName.unwrap(meshName): java.lang.String)
      .optionallyWith(
        meshOwner.map(value => AccountId.unwrap(value): java.lang.String)
      )(_.meshOwner)
      .routeName(ResourceName.unwrap(routeName): java.lang.String)
      .spec(spec.buildAwsValue())
      .virtualRouterName(
        ResourceName.unwrap(virtualRouterName): java.lang.String
      )
      .build()
  }
  def asReadOnly: zio.aws.appmesh.model.UpdateRouteRequest.ReadOnly =
    zio.aws.appmesh.model.UpdateRouteRequest.wrap(buildAwsValue())
}
object UpdateRouteRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.appmesh.model.UpdateRouteRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.appmesh.model.UpdateRouteRequest =
      zio.aws.appmesh.model.UpdateRouteRequest(
        clientToken.map(value => value),
        meshName,
        meshOwner.map(value => value),
        routeName,
        spec.asEditable,
        virtualRouterName
      )
    def clientToken: Optional[String]
    def meshName: ResourceName
    def meshOwner: Optional[AccountId]
    def routeName: ResourceName
    def spec: zio.aws.appmesh.model.RouteSpec.ReadOnly
    def virtualRouterName: ResourceName
    def getClientToken: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("clientToken", clientToken)
    def getMeshName: ZIO[Any, Nothing, ResourceName] = ZIO.succeed(meshName)
    def getMeshOwner: ZIO[Any, AwsError, AccountId] =
      AwsError.unwrapOptionField("meshOwner", meshOwner)
    def getRouteName: ZIO[Any, Nothing, ResourceName] = ZIO.succeed(routeName)
    def getSpec: ZIO[Any, Nothing, zio.aws.appmesh.model.RouteSpec.ReadOnly] =
      ZIO.succeed(spec)
    def getVirtualRouterName: ZIO[Any, Nothing, ResourceName] =
      ZIO.succeed(virtualRouterName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.appmesh.model.UpdateRouteRequest
  ) extends zio.aws.appmesh.model.UpdateRouteRequest.ReadOnly {
    override val clientToken: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.clientToken())
      .map(value => value: String)
    override val meshName: ResourceName =
      zio.aws.appmesh.model.primitives.ResourceName(impl.meshName())
    override val meshOwner: Optional[AccountId] = zio.aws.core.internal
      .optionalFromNullable(impl.meshOwner())
      .map(value => zio.aws.appmesh.model.primitives.AccountId(value))
    override val routeName: ResourceName =
      zio.aws.appmesh.model.primitives.ResourceName(impl.routeName())
    override val spec: zio.aws.appmesh.model.RouteSpec.ReadOnly =
      zio.aws.appmesh.model.RouteSpec.wrap(impl.spec())
    override val virtualRouterName: ResourceName =
      zio.aws.appmesh.model.primitives.ResourceName(impl.virtualRouterName())
  }
  def wrap(
      impl: software.amazon.awssdk.services.appmesh.model.UpdateRouteRequest
  ): zio.aws.appmesh.model.UpdateRouteRequest.ReadOnly = new Wrapper(impl)
}
